**DFSNBA_Team_Builder**

**Purpose**

Create optimized NBA draftkings lineups with sampling

**What to do high level**

1.Import Draftkings Upload File [DK_Upload_Page](https://www.draftkings.com/lineup/upload)

2.Build a team or teams based on the amount of teams and amount of sampling you want

3.Use Linear Programming to optimze the teams for the maximum amount of points while staying under the salary cap


**End Notes**

This package was created to use the draftkings lineup file for any given night and run an optimization function on it in order to create the most efficient teams based on the average points columns. 


[GitHub_Repo](https://github.com/Blex42/DFS_NBA_Team_Builder)
